        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <br>1,3,4,5,9,11,12,13,14,15,19,20,24,26,28,30,31,33,36,37,38,39,41,43,46,48,50';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <strong>control</strong><br>0,2,6,7,8,10,16,17,18,21,22,23,25,27,29,32,34,35,40,42,44,45,47,49';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <br>1,3,4,5,9,11,12,13,14,15,19,20,24,26,28,30,31,33,36,37,38,39,41,43,46,48,50';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <strong>control</strong><br>0,2,6,7,8,10,16,17,18,21,22,23,25,27,29,32,34,35,40,42,44,45,47,49';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <br>1,3,4,5,9,11,12,13,14,15,19,20,24,26,28,30,31,33,36,37,38,39,41,43,46,48,50';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <strong>control</strong><br>0,2,6,7,8,10,16,17,18,21,22,23,25,27,29,32,34,35,40,42,44,45,47,49';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <br>1,3,4,5,9,11,12,13,14,15,19,20,24,26,28,30,31,33,36,37,38,39,41,43,46,48,50';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <strong>control</strong><br>0,2,6,7,8,10,16,17,18,21,22,23,25,27,29,32,34,35,40,42,44,45,47,49';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <br>1,3,4,5,9,11,12,13,14,15,19,20,24,26,28,30,31,33,36,37,38,39,41,43,46,48,50';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <strong>control</strong><br>0,2,6,7,8,10,16,17,18,21,22,23,25,27,29,32,34,35,40,42,44,45,47,49';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <br>1,3,4,5,9,11,12,13,14,15,19,20,24,26,28,30,31,33,36,37,38,39,41,43,46,48,50';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <strong>control</strong><br>0,2,6,7,8,10,16,17,18,21,22,23,25,27,29,32,34,35,40,42,44,45,47,49';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 27 <br>1,3,4,5,9,11,12,13,14,15,19,20,24,26,28,30,31,33,36,37,38,39,41,43,46,48,50';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260604 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 24 <strong>control</strong><br>0,2,6,7,8,10,16,17,18,21,22,23,25,27,29,32,34,35,40,42,44,45,47,49';}
}
